/*
 * The MIT License (MIT)
 * 
 * Copyright (c) 2013 Ian Hlavats.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * 
 */
package com.mycompany.model;

import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;

/**
 * JPA entity for a relationship between two users.
 * 
 * @author Ian Hlavats (ian@tarantulaconsulting.com)
 * 
 */
@Entity
@Table(uniqueConstraints = @UniqueConstraint(columnNames = { "from_user", "to_user",
		"relationshipType" }))
public class UserRelationship extends AbstractEntity {

	/**
	 * 
	 */
	private static final long serialVersionUID = -5157091586647676960L;

	private RelationshipType relationshipType;

	private User fromUser;

	private User toUser;

	@Enumerated(EnumType.STRING)
	public RelationshipType getRelationshipType() {
		return relationshipType;
	}

	@ManyToOne
	public User getFromUser() {
		return fromUser;
	}

	@ManyToOne
	public User getToUser() {
		return toUser;
	}

	public void setRelationshipType(RelationshipType contactType) {
		this.relationshipType = contactType;
	}

	public void setFromUser(User firstUser) {
		this.fromUser = firstUser;
	}

	public void setToUser(User secondUser) {
		this.toUser = secondUser;
	}

}
